# Release Notes
---

## [1.6.2](https://github.com/osl-incubator/makim/compare/1.6.1...1.6.2) (2023-03-08)


### Bug Fixes

* Fix the mechanism for killing child processes when CTRL+C is pressed ([#25](https://github.com/osl-incubator/makim/issues/25)) ([00a9aff](https://github.com/osl-incubator/makim/commit/00a9affd98eb3259700cba3ac9173e5b9dcc5840))

## [1.6.1](https://github.com/osl-incubator/makim/compare/1.6.0...1.6.1) (2023-03-08)


### Bug Fixes

* Fix IF statement and arguments used by dependencies ([#24](https://github.com/osl-incubator/makim/issues/24)) ([e03886e](https://github.com/osl-incubator/makim/commit/e03886ef0340e1233926946397b6dda0432541f6))

# [1.6.0](https://github.com/osl-incubator/makim/compare/1.5.0...1.6.0) (2023-02-26)


### Features

* Add support for user defined shell app ([#22](https://github.com/osl-incubator/makim/issues/22)) ([dd4a7db](https://github.com/osl-incubator/makim/commit/dd4a7dbab93e7a2ea44bbfb3f1e2ad9b65da9b29))

# [1.5.0](https://github.com/osl-incubator/makim/compare/1.4.0...1.5.0) (2023-02-08)


### Features

* Add required argument option ([#16](https://github.com/osl-incubator/makim/issues/16)) ([dc79486](https://github.com/osl-incubator/makim/commit/dc794861f1230608306337e9e07283d0c8c56dd0))

# [1.4.0](https://github.com/osl-incubator/makim/compare/1.3.0...1.4.0) (2023-02-07)


### Features

* Add support to dot env file in the top level in the makim file ([#15](https://github.com/osl-incubator/makim/issues/15)) ([ee07cdb](https://github.com/osl-incubator/makim/commit/ee07cdbef497cd0183be97524e1d12cc06e7b589))

# [1.3.0](https://github.com/osl-incubator/makim/compare/1.2.0...1.3.0) (2023-02-05)


### Features

* Add dependency argument ([#13](https://github.com/osl-incubator/makim/issues/13)) ([7f28c68](https://github.com/osl-incubator/makim/commit/7f28c6873a78aa608106fdf9559d303ab5469b74))

# [1.2.0](https://github.com/osl-incubator/makim/compare/1.1.1...1.2.0) (2023-02-03)


### Features

* Add initial support for arguments ([#11](https://github.com/osl-incubator/makim/issues/11)) ([4d105d0](https://github.com/osl-incubator/makim/commit/4d105d0b6b1488af298877f8c0e9390256c5b559))

## [1.1.1](https://github.com/osl-incubator/makim/compare/1.1.0...1.1.1) (2023-02-03)


### Bug Fixes

* Fix release workflow ([#10](https://github.com/osl-incubator/makim/issues/10)) ([39146bb](https://github.com/osl-incubator/makim/commit/39146bb3946661c9630b1ad2bceb7eae297fbad5))

# [1.1.0](https://github.com/osl-incubator/makim/compare/1.0.2...1.1.0) (2023-02-03)


### Features

* Add support for variables for the target group ([#9](https://github.com/osl-incubator/makim/issues/9)) ([e3aa389](https://github.com/osl-incubator/makim/commit/e3aa389a07b7f5677328420f1389e84ed71bc7b3))

## [1.0.2](https://github.com/osl-incubator/makim/compare/1.0.1...1.0.2) (2023-01-26)


### Bug Fixes

* Fix support for Python 3.7.1, 3.8, 3.9, 3.10 ([#7](https://github.com/osl-incubator/makim/issues/7)) ([418f3de](https://github.com/osl-incubator/makim/commit/418f3de6dc4e5f1b963b32da9736163ea78ce5f5))

## [1.0.1](https://github.com/osl-incubator/makim/compare/1.0.0...1.0.1) (2023-01-25)


### Bug Fixes

* Suppress the sh traceback message error ([#5](https://github.com/osl-incubator/makim/issues/5)) ([dc3f4ad](https://github.com/osl-incubator/makim/commit/dc3f4ad1a949cd72e628742107cf5bd368721b7e))
